@@ -1,4 +1,4 @@
-# copyright 2011 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
+# copyright 2011-2013 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
 # contact http://www.logilab.fr -- mailto:contact@logilab.fr
 #
 # This program is free software: you can redistribute it and/or modify it under
@@ -30,13 +30,15 @@ class source_repository(RelationDefinition):
 class introduced_by(RelationDefinition):
     subject = 'Ticket'
     object = 'Revision'
-    constraints = [RQLConstraint('S concerns P, O from_repository R, P source_repository R')]
+    constraints = [RQLConstraint('S concerns P, O from_repository R, '
+                                 'P source_repository R')]
 
 
 class closed_by(RelationDefinition):
     subject = 'Ticket'
     object = 'Revision'
-    constraints = [RQLConstraint('S concerns P, O from_repository R, P source_repository R')]
+    constraints = [RQLConstraint('S concerns P, O from_repository R, '
+                                 'P source_repository R')]
 
 if 'Patch' in context.defined:
     from cubes.vcreview.schema import Patch
@@ -45,12 +47,14 @@ if 'Patch' in context.defined:
     class patch_ticket(RelationDefinition):
         subject = 'Patch'
         object = 'Ticket'
-        constraints = [RQLConstraint('S patch_repository PR, R has_patch_repository PR, '
-                                     'O concerns P, P source_repository R')]
+        constraints = [RQLConstraint('S patch_revision RE, '
+                                     'RE from_repository R, '
+                                     'O concerns P, '
+                                     'P source_repository R')]
 
 
     class require_permission(RelationDefinition):
-        subject = ('Patch', 'Task', 'VersionContent', 'InsertionPoint')
+        subject = ('Patch', 'Task', 'InsertionPoint')
         object = 'CWPermission'
 
         Task.__permissions__.update({'add': ('managers', 'staff',),
